<?php
namespace Inti\Wp\Middleware;

use Inti\Config\Middleware\ConfigMiddleware;
use Inti\Wp\Plugin\PluginLoader;
use Psr\Container\ContainerInterface;
use Psr\Http\Server\MiddlewareInterface;
use Laminas\Stratigility\MiddlewarePipe;

/**
 * Class WordPressMiddlewareFactory
 *
 * @package Inti\Wp
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class WpBootstrapFactory
{
    /**
     * @param ContainerInterface $container
     * @return MiddlewareInterface
     */
    public function __invoke(ContainerInterface $container): MiddlewareInterface
    {
        $middleware = new MiddlewarePipe();

        $middleware->pipe($container->get(ConfigMiddleware::class));
        $middleware->pipe(new WpBootstrap());
        $middleware->pipe(new WpLoader());
        $middleware->pipe(new WpVersion());
        $middleware->pipe(new WpDb());
        $middleware->pipe(new WpCache());
        $middleware->pipe(new WpConstants());
        $middleware->pipe(new WpSetup());
        $middleware->pipe(new WpLocale());
        $middleware->pipe(new WpTheme());
        $middleware->pipe(new WpPlugins($container->get(PluginLoader::class)));
        $middleware->pipe(new WpInit());

        return $middleware;
    }
}
