<?php
namespace Inti\Wp\Middleware;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class WpConstants
 *
 * @package Inti\Wp\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class WpConstants implements MiddlewareInterface
{
    /**
     * Process an incoming server request.
     *
     * Processes an incoming server request in order to produce a response.
     * If unable to produce the response itself, it may delegate to the provided
     * request handler to do so.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if (!$request->getAttribute('did_init', false)) {
            $this->defineConstants();
        }

        return $handler->handle($request);
    }

    private function defineConstants(): void
    {
        define('AUTH_KEY',         '');
        define('SECURE_AUTH_KEY',  '');
        define('LOGGED_IN_KEY',    '');
        define('NONCE_KEY',        '');
        define('AUTH_SALT',        '');
        define('SECURE_AUTH_SALT', '');
        define('LOGGED_IN_SALT',   '');
        define('NONCE_SALT',       '');

        // Set initial default constants including WP_MEMORY_LIMIT, WP_MAX_MEMORY_LIMIT, WP_DEBUG, SCRIPT_DEBUG, WP_CONTENT_DIR and WP_CACHE.
        wp_initial_constants();

        // Define WP_LANG_DIR if not set.
        wp_set_lang_dir();

        // Define constants that rely on the API to obtain the default value.
        // Define must-use plugin directory constants, which may be overridden in the sunrise.php drop-in.
        wp_plugin_directory_constants();

        // Define constants after multisite is loaded.
        wp_cookie_constants();

        // Define the template related constants.
        wp_templating_constants();

        // Define constants which affect functionality if not already defined.
        wp_functionality_constants();

        // Create common globals.
        require ABSPATH . WPINC . '/vars.php';
    }
}
