<?php
namespace Inti\Wp\Middleware;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class WpLoader
 *
 * @package Inti\Wp\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class WpLoader implements MiddlewareInterface
{
    /**
     * Process an incoming server request.
     *
     * Processes an incoming server request in order to produce a response.
     * If unable to produce the response itself, it may delegate to the provided
     * request handler to do so.
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if (!$request->getAttribute('did_init')) {
            $this->loadFiles($request);
        }
        
        return $handler->handle($request);
    }

    /**
     * @param ServerRequestInterface $request
     */
    private function loadFiles(ServerRequestInterface $request): void
    {
        $uri = $request->getUri();
        define('WP_HOME', rtrim((string) $uri->withQuery('')->withPath('/'), '/'));
        define('WP_SITEURL', WP_HOME . '/wp');
        define('WP_CONTENT_DIR', dirname(ABSPATH));
        define('WP_CONTENT_URL', WP_HOME);

        define('WPINC', 'wp-includes');

        require ABSPATH . WPINC . '/load.php';
        require ABSPATH . WPINC . '/error-protection.php';
        require ABSPATH . WPINC . '/default-constants.php';
        require_once ABSPATH . WPINC . '/plugin.php';

        require ABSPATH . WPINC . '/compat.php';
        require ABSPATH . WPINC . '/formatting.php';
        require ABSPATH . WPINC . '/meta.php';
        require ABSPATH . WPINC . '/functions.php';
        require ABSPATH . WPINC . '/pomo/mo.php';

        require_once ABSPATH . WPINC . '/l10n.php';

        // Load most of WordPress.
        require ABSPATH . WPINC . '/capabilities.php';
        require ABSPATH . WPINC . '/query.php';
        require ABSPATH . WPINC . '/theme.php';
        require ABSPATH . WPINC . '/template.php';
        require ABSPATH . WPINC . '/user.php';
        require ABSPATH . WPINC . '/general-template.php';
        require ABSPATH . WPINC . '/link-template.php';
        require ABSPATH . WPINC . '/author-template.php';
        require ABSPATH . WPINC . '/post.php';
        require ABSPATH . WPINC . '/post-template.php';
        require ABSPATH . WPINC . '/revision.php';
        require ABSPATH . WPINC . '/post-formats.php';
        require ABSPATH . WPINC . '/post-thumbnail-template.php';
        require ABSPATH . WPINC . '/category.php';
        require ABSPATH . WPINC . '/category-template.php';
        require ABSPATH . WPINC . '/comment.php';
        require ABSPATH . WPINC . '/comment-template.php';
        require ABSPATH . WPINC . '/rewrite.php';
        require ABSPATH . WPINC . '/feed.php';
        require ABSPATH . WPINC . '/bookmark.php';
        require ABSPATH . WPINC . '/bookmark-template.php';
        require ABSPATH . WPINC . '/kses.php';
        require ABSPATH . WPINC . '/cron.php';
        require ABSPATH . WPINC . '/deprecated.php';
        require ABSPATH . WPINC . '/script-loader.php';
        require ABSPATH . WPINC . '/taxonomy.php';
        require ABSPATH . WPINC . '/update.php';
        require ABSPATH . WPINC . '/canonical.php';
        require ABSPATH . WPINC . '/shortcodes.php';
        require ABSPATH . WPINC . '/embed.php';
        require ABSPATH . WPINC . '/media.php';
        require ABSPATH . WPINC . '/http.php';
        require ABSPATH . WPINC . '/class-http.php';
        require ABSPATH . WPINC . '/widgets.php';
        require ABSPATH . WPINC . '/nav-menu.php';
        require ABSPATH . WPINC . '/nav-menu-template.php';
        require ABSPATH . WPINC . '/admin-bar.php';
        require ABSPATH . WPINC . '/rest-api.php';
        require ABSPATH . WPINC . '/sitemaps.php';
        require ABSPATH . WPINC . '/class-wp-block-type.php';
        require ABSPATH . WPINC . '/class-wp-block-pattern-categories-registry.php';
        require ABSPATH . WPINC . '/class-wp-block-patterns-registry.php';
        require ABSPATH . WPINC . '/class-wp-block-styles-registry.php';
        require ABSPATH . WPINC . '/class-wp-block-type-registry.php';
        require ABSPATH . WPINC . '/class-wp-block.php';
        require ABSPATH . WPINC . '/class-wp-block-list.php';
        require ABSPATH . WPINC . '/class-wp-block-parser.php';
        require ABSPATH . WPINC . '/blocks.php';
        require ABSPATH . WPINC . '/blocks/index.php';
        require ABSPATH . WPINC . '/block-patterns.php';
        require ABSPATH . WPINC . '/block-supports/align.php';
        require ABSPATH . WPINC . '/block-supports/colors.php';
        require ABSPATH . WPINC . '/block-supports/custom-classname.php';
        require ABSPATH . WPINC . '/block-supports/generated-classname.php';
        require ABSPATH . WPINC . '/block-supports/typography.php';

        // Load pluggable functions.
        require ABSPATH . WPINC . '/pluggable.php';
        require ABSPATH . WPINC . '/pluggable-deprecated.php';
    }
}
