<?php
namespace Inti\Wp\Middleware;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use WP_Locale;
use WP_Locale_Switcher;

/**
 * Class WpLocale
 *
 * @package Inti\Wp\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-bartog
 */
final class WpLocale implements MiddlewareInterface
{
    /**
     * Process an incoming server request.
     *
     * Processes an incoming server request in order to produce a response.
     * If unable to produce the response itself, it may delegate to the provided
     * request handler to do so.
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if (!$request->getAttribute('did_init', false)) {
            $this->initLocale();
        }

        return $handler->handle($request);
    }

    private function initLocale(): void
    {
        // Load the default text localization domain.
        load_default_textdomain();
        
        $locale      = get_locale();
        $locale_file = WP_LANG_DIR . "/$locale.php";
        if ((0 === validate_file($locale)) && is_readable($locale_file)) {
            require $locale_file;
        }
        unset($locale_file);

        /**
         * WordPress Locale object for loading locale domain date and various strings.
         *
         * @global WP_Locale $wp_locale WordPress date and time locale object.
         * @since 2.1.0
         */
        $GLOBALS['wp_locale'] = new WP_Locale();

        /**
         * WordPress Locale Switcher object for switching locales.
         *
         * @since 4.7.0
         *
         * @global WP_Locale_Switcher $wp_locale_switcher WordPress locale switcher object.
         */
        $GLOBALS['wp_locale_switcher'] = new WP_Locale_Switcher();
        $GLOBALS['wp_locale_switcher']->init();
    }
}
