<?php
namespace Inti\Wp\Middleware;

use Inti\Wp\Plugin\PluginLoader;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class WpPlugins
 *
 * @package Inti\Wp\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class WpPlugins implements MiddlewareInterface
{
    private PluginLoader $pluginLoader;

    /**
     * Konstruktor.
     *
     * @param PluginLoader $pluginLoader
     */
    public function __construct(PluginLoader $pluginLoader)
    {
        $this->pluginLoader = $pluginLoader;
    }
    
    /**
     * Process an incoming server request.
     *
     * Processes an incoming server request in order to produce a response.
     * If unable to produce the response itself, it may delegate to the provided
     * request handler to do so.
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if (!$request->getAttribute('did_init', false)) {
            $this->initPlugins();
        }
        
        return $handler->handle($request);
    }
    
    public function initPlugins(): void
    {
        $GLOBALS['wp_plugin_paths'] = array();

        // Load active plugins.
        foreach (wp_get_active_and_valid_plugins() as $plugin) {
            wp_register_plugin_realpath($plugin);
            include_once $plugin;

            /**
             * Fires once a single activated plugin has loaded.
             *
             * @since 5.1.0
             *
             * @param string $plugin Full path to the plugin's main file.
             */
            do_action('plugin_loaded', $plugin);
        }

        $this->pluginLoader->attach();

        /**
         * Fires once activated plugins have loaded.
         *
         * Pluggable functions are also available at this point in the loading order.
         *
         * @since 1.5.0
         */
        do_action('plugins_loaded');
    }
}
