<?php
namespace Inti\Wp\Middleware;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use WP;
use WP_Embed;
use WP_Query;
use WP_Rewrite;
use WP_Roles;
use WP_Widget_Factory;

/**
 * Class WpSetup
 *
 * @package Inti\Wp\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class WpSetup implements MiddlewareInterface
{
    /**
     * Process an incoming server request.
     *
     * Processes an incoming server request in order to produce a response.
     * If unable to produce the response itself, it may delegate to the provided
     * request handler to do so.
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if (!$request->getAttribute('did_init', false)) {
            $this->setupWp();
        }

        return $handler->handle($request);
    }

    private function setupWp(): void
    {
        // Make taxonomies and posts available to plugins and themes.
        // @plugin authors: warning: these get registered again on the init hook.
        create_initial_taxonomies();
        create_initial_post_types();

        // Attach the default filters.
        require ABSPATH . WPINC . '/default-filters.php';

        $GLOBALS['wp_embed'] = new WP_Embed();

        /**
         * WordPress Query object
         *
         * @global WP_Query $wp_the_query WordPress Query object.
         * @since 2.0.0
         */
        $GLOBALS['wp_the_query'] = new WP_Query();

        /**
         * Holds the reference to @see $wp_the_query
         * Use this global for WordPress queries
         *
         * @global WP_Query $wp_query WordPress Query object.
         * @since 1.5.0
         */
        $GLOBALS['wp_query'] = $GLOBALS['wp_the_query'];

        /**
         * WordPress Widget Factory Object
         *
         * @global WP_Widget_Factory $wp_widget_factory
         * @since 2.8.0
         */
        $GLOBALS['wp_widget_factory'] = new WP_Widget_Factory();

        /**
         * WordPress User Roles
         *
         * @global WP_Roles $wp_roles WordPress role management object.
         * @since 2.0.0
         */
        $GLOBALS['wp_roles'] = new WP_Roles();

        /**
         * Holds the WordPress Rewrite object for creating pretty URLs
         *
         * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
         * @since 1.5.0
         */
        $GLOBALS['wp_rewrite'] = new WP_Rewrite();

        /**
         * WordPress Object
         *
         * @global WP $wp Current WordPress environment instance.
         * @since 2.0.0
         */
        $GLOBALS['wp'] = new WP();
    }
}
