<?php
namespace Inti\Wp\Middleware;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class WpTheme
 *
 * @package Inti\Wp\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class WpTheme implements MiddlewareInterface
{
    /**
     * Process an incoming server request.
     *
     * Processes an incoming server request in order to produce a response.
     * If unable to produce the response itself, it may delegate to the provided
     * request handler to do so.
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if (!$request->getAttribute('did_init', false)) {
            $this->loadTheme();
        }

        return $handler->handle($request);
    }

    private function loadTheme(): void
    {
        // Register the default theme directory root.
        register_theme_directory(get_theme_root());

        /**
         * Fires before the theme is loaded.
         *
         * @since 2.6.0
         */
        do_action('setup_theme');

        // Load the functions for the active theme, for both parent and child theme if applicable.
        foreach (wp_get_active_and_valid_themes() as $theme) {
            if (file_exists($theme . '/functions.php')) {
                /** @noinspection PhpIncludeInspection */
                include $theme . '/functions.php';
            }
        }
        unset($theme);

        /**
         * Fires after the theme is loaded.
         *
         * @since 3.0.0
         */
        do_action('after_setup_theme');
    }
}
