<?php
namespace Inti\Wp\Middleware;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class WpVersion
 *
 * @package Inti\Wp\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class WpVersion implements MiddlewareInterface
{
    /**
     * Process an incoming server request.
     *
     * Processes an incoming server request in order to produce a response.
     * If unable to produce the response itself, it may delegate to the provided
     * request handler to do so.
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if (!$request->getAttribute('did_init', false)) {
            $this->initVersion();
        }

        return $handler->handle($request);
    }

    private function initVersion(): void
    {
        /**
         * Version information for the current WordPress release.
         *
         * These can't be directly globalized in version.php. When updating,
         * we're including version.php from another installation and don't want
         * these values to be overridden if already set.
         *
         * @global string $wp_version             The WordPress version string.
         * @global int    $wp_db_version          WordPress database version.
         * @global string $tinymce_version        TinyMCE version.
         * @global string $required_php_version   The required PHP version string.
         * @global string $required_mysql_version The required MySQL version string.
         * @global string $wp_local_package       Locale code of the package.
         */
        global /** @noinspection PhpUnusedLocalVariableInspection */
        $wp_version, $wp_db_version, $tinymce_version, $required_php_version, $required_mysql_version, $wp_local_package;
        require ABSPATH . WPINC . '/version.php';
    }
}
